@@ -1,6 +1,6 @@
 import importlib.util
 import sys
-import warnings, os, json
+import warnings, os, json, yaml
 from collections import ChainMap
 from dataclasses import dataclass
 from typing import Callable, overload, final, Self
@@ -51,10 +51,9 @@ def _maybe_get_frame_name(frame_name, script_path):
 
 def _get_config_from_master(inner_path, jinja_repo_source):
     _inner_path = Path(inner_path)
-    with open(os.path.join(jinja_repo_source.root_dir, "master_config.json"), 'r') as f:
-        master_config = json.load(f)
-    return master_config[str(_inner_path.parent).replace("\\", "/")][str(_inner_path.name)]
-
+    with open(os.path.join(jinja_repo_source.root_dir, "master_config.yaml"), 'r') as f: # TODO set this as a JinjaRepo
+        master_config = yaml.safe_load(f)
+    return master_config[_inner_path.parent.as_posix()][str(_inner_path.name)]
 
 
 class DataManager:
