@@ -31,5 +31,3 @@ class InsertError(Exception):
     """Inserts not correctly entered into sql script"""
     pass
 
-class GranularityError(Exception):
-    """Raised when the granularity of a dataframe changes unexpectedly, usually due to a join"""
\ No newline at end of file
